@@ -9,11 +9,17 @@ class Price:
     top_price: float = 0.0
     cautionhour_type: str = ""
 
+@dataclass
+class Charger:
+    chargertype: str = ""
+    chargerid: str = ""
+    powerswitch: str = ""
+    powermeter: str = ""
+
 @dataclass
 class HubOptions:
     locale: str = field(init=False)
-    chargertype: str = field(init=False)
-    chargerid: str = field(init=False)
+    charger: Charger = Charger()
     price: Price = Price()
     peaqev_lite: bool = False
     powersensor_includes_car: bool = False
